==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/SubscriberStatusFluentImpl.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SubscriberStatusFluentImpl<A extends SubscriberStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SubscriberStatusFluent<A> {

    private String message;
    private Long observedGeneration;
    private String ready;
    private String uid;

    public SubscriberStatusFluentImpl() {
    }

    public SubscriberStatusFluentImpl(SubscriberStatus instance) {
        this.withMessage(instance.getMessage()); 
        this.withObservedGeneration(instance.getObservedGeneration()); 
        this.withReady(instance.getReady()); 
        this.withUid(instance.getUid()); 
    }

    public String getMessage() {
        return this.message;
    }

    public A withMessage(String message) {
        this.message=message; return (A) this;
    }

    public Boolean hasMessage() {
        return this.message != null;
    }

    public A withNewMessage(String arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuilder arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1) {
        return (A)withMessage(new String(arg1));
    }

    public Long getObservedGeneration() {
        return this.observedGeneration;
    }

    public A withObservedGeneration(Long observedGeneration) {
        this.observedGeneration=observedGeneration; return (A) this;
    }

    public Boolean hasObservedGeneration() {
        return this.observedGeneration != null;
    }

    public String getReady() {
        return this.ready;
    }

    public A withReady(String ready) {
        this.ready=ready; return (A) this;
    }

    public Boolean hasReady() {
        return this.ready != null;
    }

    public A withNewReady(String arg1) {
        return (A)withReady(new String(arg1));
    }

    public A withNewReady(StringBuilder arg1) {
        return (A)withReady(new String(arg1));
    }

    public A withNewReady(StringBuffer arg1) {
        return (A)withReady(new String(arg1));
    }

    public String getUid() {
        return this.uid;
    }

    public A withUid(String uid) {
        this.uid=uid; return (A) this;
    }

    public Boolean hasUid() {
        return this.uid != null;
    }

    public A withNewUid(String arg1) {
        return (A)withUid(new String(arg1));
    }

    public A withNewUid(StringBuilder arg1) {
        return (A)withUid(new String(arg1));
    }

    public A withNewUid(StringBuffer arg1) {
        return (A)withUid(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SubscriberStatusFluentImpl that = (SubscriberStatusFluentImpl) o;
        if (message != null ? !message.equals(that.message) :that.message != null) return false;
        if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
        if (ready != null ? !ready.equals(that.ready) :that.ready != null) return false;
        if (uid != null ? !uid.equals(that.uid) :that.uid != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(message,  observedGeneration,  ready,  uid,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/SubscriberStatusFluentImpl.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SubscriberStatusFluentImpl<A extends SubscriberStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SubscriberStatusFluent<A> {

    private String message;
    private Long observedGeneration;
    private String ready;
    private String uid;

    public SubscriberStatusFluentImpl() {
    }

    public SubscriberStatusFluentImpl(SubscriberStatus instance) {
        this.withMessage(instance.getMessage()); 
        this.withObservedGeneration(instance.getObservedGeneration()); 
        this.withReady(instance.getReady()); 
        this.withUid(instance.getUid()); 
    }

    public String getMessage() {
        return this.message;
    }

    public A withMessage(String message) {
        this.message=message; return (A) this;
    }

    public Boolean hasMessage() {
        return this.message != null;
    }

    public A withNewMessage(StringBuilder arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(int[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(char[] arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(byte[] arg1,int arg2) {
        return (A)withMessage(new String(arg1, arg2));
    }

    public A withNewMessage(byte[] arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(char[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(byte[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMessage(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMessage(String arg1) {
        return (A)withMessage(new String(arg1));
    }

    public Long getObservedGeneration() {
        return this.observedGeneration;
    }

    public A withObservedGeneration(Long observedGeneration) {
        this.observedGeneration=observedGeneration; return (A) this;
    }

    public Boolean hasObservedGeneration() {
        return this.observedGeneration != null;
    }

    public A withNewObservedGeneration(long arg1) {
        return (A)withObservedGeneration(new Long(arg1));
    }

    public String getReady() {
        return this.ready;
    }

    public A withReady(String ready) {
        this.ready=ready; return (A) this;
    }

    public Boolean hasReady() {
        return this.ready != null;
    }

    public A withNewReady(StringBuilder arg1) {
        return (A)withReady(new String(arg1));
    }

    public A withNewReady(int[] arg1,int arg2,int arg3) {
        return (A)withReady(new String(arg1, arg2, arg3));
    }

    public A withNewReady(char[] arg1) {
        return (A)withReady(new String(arg1));
    }

    public A withNewReady(StringBuffer arg1) {
        return (A)withReady(new String(arg1));
    }

    public A withNewReady(byte[] arg1,int arg2) {
        return (A)withReady(new String(arg1, arg2));
    }

    public A withNewReady(byte[] arg1) {
        return (A)withReady(new String(arg1));
    }

    public A withNewReady(char[] arg1,int arg2,int arg3) {
        return (A)withReady(new String(arg1, arg2, arg3));
    }

    public A withNewReady(byte[] arg1,int arg2,int arg3) {
        return (A)withReady(new String(arg1, arg2, arg3));
    }

    public A withNewReady(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withReady(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewReady(String arg1) {
        return (A)withReady(new String(arg1));
    }

    public String getUid() {
        return this.uid;
    }

    public A withUid(String uid) {
        this.uid=uid; return (A) this;
    }

    public Boolean hasUid() {
        return this.uid != null;
    }

    public A withNewUid(StringBuilder arg1) {
        return (A)withUid(new String(arg1));
    }

    public A withNewUid(int[] arg1,int arg2,int arg3) {
        return (A)withUid(new String(arg1, arg2, arg3));
    }

    public A withNewUid(char[] arg1) {
        return (A)withUid(new String(arg1));
    }

    public A withNewUid(StringBuffer arg1) {
        return (A)withUid(new String(arg1));
    }

    public A withNewUid(byte[] arg1,int arg2) {
        return (A)withUid(new String(arg1, arg2));
    }

    public A withNewUid(byte[] arg1) {
        return (A)withUid(new String(arg1));
    }

    public A withNewUid(char[] arg1,int arg2,int arg3) {
        return (A)withUid(new String(arg1, arg2, arg3));
    }

    public A withNewUid(byte[] arg1,int arg2,int arg3) {
        return (A)withUid(new String(arg1, arg2, arg3));
    }

    public A withNewUid(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withUid(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewUid(String arg1) {
        return (A)withUid(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SubscriberStatusFluentImpl that = (SubscriberStatusFluentImpl) o;
        if (message != null ? !message.equals(that.message) :that.message != null) return false;
        if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
        if (ready != null ? !ready.equals(that.ready) :that.ready != null) return false;
        if (uid != null ? !uid.equals(that.uid) :that.uid != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(message,  observedGeneration,  ready,  uid,  super.hashCode());
    }

}
